<p align="center">
<img src="https://github.com/vortezwohl/Dipamkara/releases/download/icon/Dipamkara.png" width="300">
</p>

<p align="center">
Powered by <a href="https://github.com/numpy/numpy">Numpy</a>
</p>

## Dipamkara is

  1. A light-weight vector database engine

  2. Easy to use

  3. Thread safe

  4. Portable

  5. Reliable

  6. Based only on Numpy

  7. Suitable for small-sized datasets

## Installation

- From [PYPI](https://pypi.org/project/dipamkara/)

    ```shell
    pip install dipamkara
    ```

- From [Github](https://github.com/vortezwohl/dipamkara/releases)

    Download .whl first then run

    ```shell
    pip install ./dipamkara-X.X.X-py3-none-any.whl
    ```